@@ -615,7 +615,7 @@ def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
     return df
 
 
-def map_conv_prob_using_dictionary(df, bv_dict, prob_dict, column:str):
+def map_conv_prob_using_dictionary(df, prob_dict, bv_dict, column:str):
     """
 
     :param df: Input Dataset
